JoltUseUntilCreator class final
Helper class for creating Until hooks in SetupWidget.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call<
T> (ReadableNode< T> source, bool predicate(T value), {bool? detach}) → Until<T> -
Creates an
Untilhook that waits forsourceto satisfypredicate. -
changed<
T> (ReadableNode< T> source, {bool? detach}) → Until<T> -
Creates an
Untilhook that waits forsourceto change from its current value. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
T> (ReadableNode< T> source, T value, {bool? detach}) → Until<T> -
Creates an
Untilhook that waits forsourceto equalvalue.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited